@@ -5,6 +5,45 @@ from kcu import sh, kpath
 
 from . import ffprobe
 
+def reduce_audio_volume(
+    path_in: str,
+    path_out: str,
+    volume: str = '0.25',
+    debug: bool = False
+) -> bool:
+    sh.sh(
+        'ffmpeg -y -i {} -filter:a "volume={}" {}'.format(path_in, volume, path_out),
+        debug=debug
+    )
+
+    return path.exists(path_out)
+
+def get_audio_from_video(
+    path_in: str,
+    path_out: str,
+    debug: bool = False
+) -> bool:
+    sh.sh(
+        'ffmpeg -y -i {} -vn -acodec copy {}'.format(path_in, path_out),
+        debug=debug
+    )
+
+    return path.exists(path_out)
+
+def mix_audios(
+    audio_path_1: str,
+    audio_path_2: str,
+    path_out: str,
+    duration: str = 'longest',
+    debug: bool = False
+) -> bool:
+    sh.sh(
+        'ffmpeg -y -i {} -i {} -filter_complex amix=inputs=2:duration={} {}'.format(audio_path_1, audio_path_2, duration, path_out),
+        debug=debug
+    )
+
+    return path.exists(path_out)
+
 def reencode_mp3(
     path_in: str,
     path_out: str,
@@ -21,9 +60,31 @@ def reencode_aac(
     path_out: str,
     debug: bool = False
 ) -> bool:
-    sh.sh(
-        'ffmpeg -y -i ' + path_in + ' -codec:a aac ' + path_out, debug=debug
-    )
+    sh.sh('ffmpeg -y -i {} -codec:a aac {}'.format(path_in, path_out), debug=debug)
+
+    return path.exists(path_out)
+
+def modify_audio(
+    path_in: str,
+    path_out: str,
+    channels: Optional[int] = None,     # 2
+    audio_rate: Optional[int] = None,   # 44100
+    bit_rate: Optional[int] = None,     # 133
+    debug: bool = False
+) -> bool:
+    cmd = 'ffmpeg -y -i {}'.format(path_in)
+
+    if channels:
+        cmd += ' -ac {}'.format(channels)
+
+    if audio_rate:
+        cmd += ' -ar {}'.format(audio_rate)
+
+    if bit_rate:
+        cmd += ' -ab {}'.format(bit_rate)
+
+    cmd += ' {}'.format(path_out)
+    sh.sh(cmd, debug=debug)
 
     return path.exists(path_out)
 
@@ -103,10 +164,12 @@ def remove_audio(
 def add_silence_to_video(
     input: str,
     output: str,
+    sample_rate: int = 48000,
+    duration: str = 'shortest',
     debug: bool = False
 ) -> bool:
     sh.sh(
-        'ffmpeg -f lavfi -y -i anullsrc=channel_layout=stereo:sample_rate=48000 -i ' + sh.path(input) + ' -c:v copy -c:a aac -shortest ' + sh.path(output), debug=debug
+        'ffmpeg -f lavfi -y -i anullsrc=channel_layout=stereo:sample_rate={} -i {} -c:v copy -c:a aac -{} {}'.format(str(sample_rate), sh.path(input), duration, sh.path(output)), debug=debug
     )
 
     return path.exists(output)
@@ -115,6 +178,7 @@ def add_audio_to_video(
     input_a: str,
     input_v: str,
     output: str,
+    duration: str = 'shortest',
     reencode: bool = False,
     debug: bool = False
 ) -> bool:
@@ -123,7 +187,7 @@ def add_audio_to_video(
     if not reencode:
         cmd += ' -c:v copy -map 0:v:0 -map 1:a:0'
     
-    cmd += ' -shortest ' + sh.path(output)
+    cmd += ' -' + duration + ' ' + sh.path(output)
 
     sh.sh(cmd, debug=debug)
 
